from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

cypress = SchLib(tool=SKIDL).add_parts(*[
        Part(name='CY7C185',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['CY7C186']),
        Part(name='CY7C194',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='CY7C199',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='CY7C261',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='CY7C263',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['CY7C264']),
        Part(name='CY7C271',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='CY7C420',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['CY7C421', 'CY7C424', 'CY7C425', 'CY7C428', 'CY7C429']),
        Part(name='CY8C4xx7LQI-4xx',dest=TEMPLATE,tool=SKIDL,keywords='CYPRESS PSOC BLE CY8 CY8C4 ARM CORTEX M0 BLUETOOTH QFN',description='Programmable System-on-Chip With Bluetooth Low Energy, 24/48-MHz ARM® Cortex®-M0 , 56-QFN',ref_prefix='U',num_units=1,fplist=['QFN-56-1EP'],do_erc=True,aliases=['CY8C4127LQI-BL473', 'CY8C4127LQI-BL453', 'CY8C4127LQI-BL483', 'CY8C4127LQI-BL493', 'CY8C4247LQI-BL473', 'CY8C4247LQI-BL453', 'CY8C4247LQI-BL463', 'CY8C4247LQI-BL483', 'CY8C4247LQI-BL493', 'CY8C4247LQQ-BL483'],pins=[
            Pin(num='1',name='VDDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='XTAL32O/P6.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='XTAL32I/P6.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='XRES',do_erc=True),
            Pin(num='5',name='P4.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='P4.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='P5.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='P5.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='VSSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VDDR',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='P0.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='P1.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='P2.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='P3.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='GANT1',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='P0.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='P1.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='P2.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='P3.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ANT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='22',name='P0.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='P1.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='P2.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='P3.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='GANT2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='P1.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='P2.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='P3.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='VDDR',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='P0.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='P1.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='P2.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='P3.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDDR',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='P0.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='P1.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='VREF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='55',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='XTAL24I',do_erc=True),
            Pin(num='26',name='P0.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='46',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='56',name='VCCD',func=Pin.PWROUT,do_erc=True),
            Pin(num='17',name='XTAL24O',func=Pin.OUTPUT,do_erc=True),
            Pin(num='27',name='P0.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='P2.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='P3.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='GND_EP',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VDDR',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='P1.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='P2.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='P3.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='P0.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='P1.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='P2.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='P3.2',func=Pin.BIDIR,do_erc=True)]),
        Part(name='CY8CMBR3002',dest=TEMPLATE,tool=SKIDL,keywords='Touch Sensor 2ch',description='CapSense Controller, 2 Sensors, SOIC-8',ref_prefix='U',num_units=1,fplist=['SOIC-8*'],do_erc=True,pins=[
            Pin(num='1',name='GPO1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='CMOD',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='CS1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='CS0',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='GPO0',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='CY8CMBR3102',dest=TEMPLATE,tool=SKIDL,keywords='Touch Sensor 2ch',description='CapSense Controller, 2 Sensors, SOIC-8',ref_prefix='U',num_units=1,fplist=['SOIC-8*'],do_erc=True,pins=[
            Pin(num='1',name='SCL',do_erc=True),
            Pin(num='2',name='CMOD',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='CS1/PS1/GPO0/SH',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='CS0/PS0',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='SDA',func=Pin.BIDIR,do_erc=True)]),
        Part(name='CY8CMBR3106S',dest=TEMPLATE,tool=SKIDL,keywords='Touch Sensor 16ch Slider',description='CapSense Controller, 16 Sensors w/ Slider, QFN-24+EP',ref_prefix='U',num_units=1,fplist=['QFN-24*'],do_erc=True,pins=[
            Pin(num='1',name='CS0/PS0',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='CS1/PS1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='CS2',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='CS3',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='CMOD',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='VCC',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='SLD10',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='SLD11',func=Pin.PASSIVE,do_erc=True),
            Pin(num='20',name='CS4',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='SLD12',func=Pin.PASSIVE,do_erc=True),
            Pin(num='21',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='SLD13',func=Pin.PASSIVE,do_erc=True),
            Pin(num='22',name='SCL',do_erc=True),
            Pin(num='13',name='SLD14',func=Pin.PASSIVE,do_erc=True),
            Pin(num='23',name='~HI~/BUZ',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='CS11/SLD20',func=Pin.PASSIVE,do_erc=True),
            Pin(num='24',name='~XRES~',do_erc=True),
            Pin(num='15',name='CS12/SLD21',func=Pin.PASSIVE,do_erc=True),
            Pin(num='25',name='EP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='CS13/SLD22',func=Pin.PASSIVE,do_erc=True),
            Pin(num='17',name='CS14/SLD23',func=Pin.PASSIVE,do_erc=True),
            Pin(num='18',name='CS15/SLD24',func=Pin.PASSIVE,do_erc=True),
            Pin(num='19',name='CS5/SH/~HI~',func=Pin.BIDIR,do_erc=True)]),
        Part(name='CY8CMBR3108',dest=TEMPLATE,tool=SKIDL,keywords='Touch Sensor 8ch',description='CapSense Controller, 8 Sensors, QFN-16+EP',ref_prefix='U',num_units=1,fplist=['QFN-16*'],do_erc=True,pins=[
            Pin(num='1',name='CS0/PS0',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='CS1/PS1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='CMOD',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='VCC',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='CS4/GPO0',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='CS5/GPO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='CS6/GPO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='CS7/GPO3/SH',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='CS2/GUARD',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='CS3',func=Pin.PASSIVE,do_erc=True),
            Pin(num='14',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='SCL',do_erc=True),
            Pin(num='16',name='~HI~/BUZ',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='EP',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='CY8CMBR3110',dest=TEMPLATE,tool=SKIDL,keywords='Touch Sensor 10ch',description='CapSense Controller, 10 Sensors, SOIC-16',ref_prefix='U',num_units=1,fplist=['SOIC-16*'],do_erc=True,pins=[
            Pin(num='1',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='SCL',do_erc=True),
            Pin(num='3',name='CS0/PS0',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='CS1/PS1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='CMOD',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='VCC',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='CS5/GPO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='CS6/GPO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='CS7/GPO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='CS8/GPO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='CS2/GUARD',func=Pin.PASSIVE,do_erc=True),
            Pin(num='14',name='CS9/GPO4/~HI~/BUZZ',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='CS3',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='CS4/SH',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='CY8CMBR3116',dest=TEMPLATE,tool=SKIDL,keywords='Touch Sensor 16ch',description='CapSense Controller, 16 Sensors, QFN-24+EP',ref_prefix='U',num_units=1,fplist=['QFN-24*'],do_erc=True,pins=[
            Pin(num='1',name='CS0/PS0',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='CS1/PS1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='CS2/GUARD',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='CS3',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='CMOD',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='VCC',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='CS15/SH/~HI~',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='CS14/GPO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='CS4',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='CS13/GPO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='CS12/GPO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='SCL',do_erc=True),
            Pin(num='13',name='CS11/GPO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='~HI~/BUZ/GPO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='CS10/GPO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='~XRES~',do_erc=True),
            Pin(num='15',name='CS9/GPO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='EP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='CS8/GPO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='CS7',func=Pin.PASSIVE,do_erc=True),
            Pin(num='18',name='CS6',func=Pin.PASSIVE,do_erc=True),
            Pin(num='19',name='CS5',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='CYBL10563-68FNXIT',dest=TEMPLATE,tool=SKIDL,keywords='CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH WLCSP',description='68-WLCSP, 48-MHz ARM® Cortex®-M0, 128KB Flash, 16kB SRAM, BLE 4.1, CAP-SENSE W/ GESTURES, 2 SCB, 4 TCPWM, I2S, 1 PWM , LCD, 1MSPS 12-BIT SAR',ref_prefix='U',num_units=1,fplist=['WLCSP_68'],do_erc=True,aliases=['CYBL10563-68FLXIT'],pins=[
            Pin(num='11',name='GANT1',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VREF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='B1',name='P2.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D1',name='P1.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='P1.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='VSSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='P0.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='P0.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='P0.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='B2',name='VSSA',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='P2.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E2',name='P1.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='P0.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='VDDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='P0.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='P0.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='P3.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='P2.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='P2.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='P2.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='P1.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='P0.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='P0.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='XTAL24O',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J3',name='VDDR',func=Pin.PWRIN,do_erc=True),
            Pin(num='A4',name='P3.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='P3.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='P3.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='P2.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='P1.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='P1.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='VSSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H4',name='XTAL24I',do_erc=True),
            Pin(num='J4',name='VDDR',func=Pin.PWRIN,do_erc=True),
            Pin(num='A5',name='VSSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B5',name='P3.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='P3.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='P2.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='P1.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='P1.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='VSSR',func=Pin.PWRIN,do_erc=True),
            Pin(num='H5',name='VSSR',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='B6',name='P3.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='P3.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='VSSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='P2.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='VSSR',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSSR',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSSR',func=Pin.PWRIN,do_erc=True),
            Pin(num='57',name='GND_EP',func=Pin.PWRIN,do_erc=True),
            Pin(num='A7',name='VCCD',func=Pin.PWROUT,do_erc=True),
            Pin(num='B7',name='XTAL32I/P6.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='XRES',do_erc=True),
            Pin(num='D7',name='P4.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='P5.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='VSSR',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='GANT2',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='ANT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='J7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='A8',name='VDDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B8',name='XTAL32O/P6.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='P4.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='P5.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='VSSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VDDR',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSSR',func=Pin.PWRIN,do_erc=True)]),
        Part(name='CYBL10x6x-56LQxx',dest=TEMPLATE,tool=SKIDL,keywords='CYPRESS PROC BLE CY8BL ARM CORTEX M0 BLUETOOTH QFN',description='Programmable Radio-on-Chip With Bluetooth Low Energy, 48-MHz ARM® Cortex®-M0 , 56-QFN',ref_prefix='U',num_units=1,fplist=['QFN_56_1EP'],do_erc=True,aliases=['CYBL10161-56LQXI', 'CYBL10162-56LQXI', 'CYBL10163-56LQXI', 'CYBL10461-56LQXI', 'CYBL10462-56LQXI', 'CYBL10463-56LQXI', 'CYBL10561-56LQXI', 'CYBL10562-56LQXI', 'CYBL10563-56LQXI', 'CYBL10563-56LQXQ'],pins=[
            Pin(num='1',name='VDDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='XTAL32O/P6.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='XTAL32I/P6.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='XRES',do_erc=True),
            Pin(num='5',name='P4.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='P4.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='P5.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='P5.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='VSSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VDDR',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='P0.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='P1.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='P2.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='P3.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='GANT1',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='P0.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='P1.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='P2.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='P3.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ANT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='22',name='P0.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='P1.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='P2.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='P3.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='GANT2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='P1.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='P2.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='P3.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='VDDR',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='P0.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='P1.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='P2.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='P3.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDDR',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='P0.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='P1.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='VREF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='55',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='XTAL24I',do_erc=True),
            Pin(num='26',name='P0.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='46',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='56',name='VCCD',func=Pin.PWROUT,do_erc=True),
            Pin(num='17',name='XTAL24O',func=Pin.OUTPUT,do_erc=True),
            Pin(num='27',name='P0.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='P2.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='P3.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='GND_EP',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VDDR',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='P1.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='P2.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='P3.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='P0.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='P1.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='P2.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='P3.2',func=Pin.BIDIR,do_erc=True)])])


# -*- coding: utf-8 -*-

# MIT license
#
# Copyright (C) 2018 by XESS Corp.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

"""
An interface from SKiDL to PySpice.
"""

# Create a SKiDL library of SPICE elements. All PySpice-related info goes into
# a pyspice dictionary that is added as an attribute to the SKiDL Part object.


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE
from skidl.tools.spice import not_implemented, add_part_to_circuit

# Pin aliases.
_POS_DIPOLE_ALIASES = ['+', 'plus', 'anode', 'A']
_NEG_DIPOLE_ALIASES = ['-', 'minus', 'm', 'negative', 'neg', 'cathode', 'C', 'K']
_POS_IN_PORT_ALIASES = ['+i', 'i+', 'input_plus', 'plus_input']
_NEG_IN_PORT_ALIASES = ['-i', 'i-', 'input_minus', 'minus_input']
_POS_OUT_PORT_ALIASES = ['+o', 'o+', 'output_plus', 'plus_output']
_NEG_OUT_PORT_ALIASES = ['-o', 'o-', 'output_minus', 'minus_output']

pyspice_lib = SchLib(tool=SKIDL).add_parts(*[
    Part(
        name='A',
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='XSPICE',
        description='XSPICE code module',
        ref_prefix='A',
        pyspice={
            'name': 'A',
            'kw': {'model':'model',},
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[]),
    Part(
        name='B',
        aliases=['behavsrc', 'BEHAVSRC', 'behavioralsource', 'BEHAVIORALSOURCE',],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='Behavioral source',
        description='Behavioral (arbitrary) source',
        ref_prefix='B',
        pyspice={
            'name': 'B',
            'kw':{
                'i':'i_expression', 'i_expression':'i_expression',
                'v':'v_expression', 'v_expression':'v_expression',
                'tc1': 'tc1', 'tc2':'tc2',
                'temp':'temperature', 'temperature':'temperature',
                'dtemp':'device_temperature', 'device_temperature':'device_temperature',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='C',
        aliases=['cap', 'CAP'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='cap capacitor',
        description='Capacitor',
        ref_prefix='C',
        pyspice={
            'name': 'C',
            'kw':{
                'value':'capacitance', 'capacitance':'capacitance',
                'model':'model', 'multiplier':'multiplier', 'm':'multiplier',
                'scale':'scale', 
                'temp':'temperature', 'temperature':'temperature',
                'dtemp':'device_temperature', 'device_temperature':'device_temperature',
                'ic':'initial_condition', 'initial_condition':'initial_condition',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='BEHAVCAP',
        aliases=['behavcap', 'behavioralcap', 'BEHAVIORALCAP',],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='behavioral capacitor',
        description='Behavioral capacitor',
        ref_prefix='C',
        pyspice={
            'name': 'BehavioralCapacitor',
            'kw':{
                'expression':'expression',
                'tc1': 'tc1', 'tc2':'tc2',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='SEMICAP',
        aliases=['semicap', 'semiconductorcap', 'SEMICONDUCTORCAP',],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='semiconductor capacitor',
        description='Semiconductor capacitor',
        ref_prefix='C',
        pyspice={
            'name': 'SemiconductorCapacitor',
            'kw':{
                'value':'capacitance', 'model':'model',
                'length':'length', 'l':'length',
                'width':'width', 'w':'width',
                'multiplier':'multiplier', 'm':'multiplier',
                'scale':'scale', 
                'temp':'temperature', 'temperature':'temperature',
                'dtemp':'device_temperature', 'device_temperature':'device_temperature',
                'ic':'initial_condition', 'initial_condition':'initial_condition',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='D',
        aliases=['diode', 'DIODE'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='diode rectifier',
        description='Diode',
        ref_prefix='D',
        pyspice={
            'name': 'D',
            'kw':{
                'model':'model', 'area':'area',
                'multiplier':'multiplier', 'm':'multiplier',
                'pj':'pj', 'off':'off', 
                'ic':'initial_condition', 'initial_condition':'initial_condition',
                'temp':'temperature', 'temperature':'temperature',
                'dtemp':'device_temperature', 'device_temperature':'device_temperature',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='E',
        aliases=['VCVS', 'vcvs'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='voltage-controlled voltage source',
        description='Voltage-controlled voltage source',
        ref_prefix='E',
        pyspice={
            'name': 'VCVS',
            'kw':{
                'gain':'voltage_gain', 'voltage_gain':'voltage_gain',
                'op':'output_plus', 'on':'output_minus', 'ip':'input_plus', 'in':'input_minus'
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='ip', func=Pin.PASSIVE, do_erc=True, alias=_POS_IN_PORT_ALIASES),
            Pin(num='2', name='in', func=Pin.PASSIVE, do_erc=True, alias=_NEG_IN_PORT_ALIASES),
            Pin(num='3', name='op', func=Pin.PASSIVE, do_erc=True, alias=_POS_OUT_PORT_ALIASES),
            Pin(num='4', name='on', func=Pin.PASSIVE, do_erc=True, alias=_NEG_OUT_PORT_ALIASES),
        ]),
    Part(
        name='NONLINV',
        aliases=['nonlinv', 'nonlinearvoltagesource', 'NONLINEARVOLTAGESOURCE'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='non-linear voltage source',
        description='Nonlinear voltage source',
        ref_prefix='E',
        pyspice={
            'name': 'NonLinearVoltageSource',
            'kw':{
                'expression':'expression', 'table':'table',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='F',
        aliases=['CCCS', 'cccs'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='current-controlled current source',
        description='Current-controlled current source',
        ref_prefix='F',
        pyspice={
            'name': 'CCCS',
            'kw':{
                'control':'source', 'source':'source',
                'gain':'current_gain', 'current_gain':'current_gain',
                'multiplier':'multiplier', 'm':'multiplier',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='G',
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='voltage-controlled current source',
        description='Voltage-controlled current source',
        ref_prefix='G',
        pyspice={
            'name': 'VCCS',
            'kw':{
                'gain':'transconductance', 'current_gain':'transconductance',
                'multiplier':'multiplier', 'm':'multiplier',
                'op':'output_plus', 'on':'output_minus', 'ip':'input_plus', 'in':'input_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='ip', func=Pin.PASSIVE, do_erc=True, alias=_POS_IN_PORT_ALIASES),
            Pin(num='2', name='in', func=Pin.PASSIVE, do_erc=True, alias=_NEG_IN_PORT_ALIASES),
            Pin(num='3', name='op', func=Pin.PASSIVE, do_erc=True, alias=_POS_OUT_PORT_ALIASES),
            Pin(num='4', name='on', func=Pin.PASSIVE, do_erc=True, alias=_NEG_OUT_PORT_ALIASES),
        ]),
    Part(
        name='NONLINI',
        aliases=['nonlinvi', 'nonlinearcurrentsource', 'NONLINEARCURRENTSOURCE'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='non-linear current source',
        description='Nonlinear current source',
        ref_prefix='G',
        pyspice={
            'name': 'NonLinearCurrentSource',
            'kw':{
                'expression':'expression', 'table':'table',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='H',
        aliases=['CCVS', 'ccvs'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='current-controlled voltage source',
        description='Current-controlled voltage source',
        ref_prefix='H',
        pyspice={
            'name': 'H',
            'kw':{
                'control':'source', 'source':'source',
                'transresistance':'transresistance',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='I',
        aliases=['i', 'cs', 'CS'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='current source',
        description='Current source',
        ref_prefix='I',
        pyspice={
            'name': 'I',
            'kw':{
                'value':'dc_value', 'dc_value':'dc_value',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='J',
        aliases=['JFET', 'jfet'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='junction field-effect transistor JFET',
        description='Junction field-effect transistor',
        ref_prefix='J',
        pyspice={
            'name': 'J',
            'kw':{
                'model':'model', 'area':'area',
                'multiplier':'multiplier', 'm':'multiplier', 'off':'off', 
                'ic':'initial_condition', 'initial_condition':'initial_condition',
                'temp':'temperature', 'temperature':'temperature',
                'd':'drain', 'g':'gate', 's':'source',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='d', func=Pin.PASSIVE, do_erc=True, alias=['drain',]),
            Pin(num='2', name='g', func=Pin.PASSIVE, do_erc=True, alias=['gate',]),
            Pin(num='3', name='s', func=Pin.PASSIVE, do_erc=True, alias=['source',]),
        ]),
    Part(
        name='K',
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='coupled mutual inductors',
        description='Coupled (mutual) inductors',
        ref_prefix='K',
        pyspice={
            'name': 'K',
            'kw': {
                'ind1':'ind1', 'ind2':'ind2', 'coupling':'coupling',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        coupled_parts=[],
        pins=[]),
    Part(
        name='L',
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='inductor choke coil reactor magnetic',
        description='Inductor',
        ref_prefix='L',
        pyspice={
            'name': 'L',
            'kw':{
                'value':'inductance', 'inductance':'inductance',
                'model':'model', 'nt':'nt',
                'multiplier':'multiplier', 'm':'multiplier',
                'scale':'scale', 
                'temp':'temperature', 'temperature':'temperature',
                'dtemp':'device_temperature', 'device_temperature':'device_temperature',
                'ic':'initial_condition', 'initial_condition':'initial_condition',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='BEHAVIND',
        aliases=['behavind', 'behavioralind', 'BEHAVIORALIND',],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='behavioral inductor',
        description='Behavioral inductor',
        ref_prefix='C',
        pyspice={
            'name': 'BehavioralInductor',
            'kw':{
                'expression':'expression',
                'tc1': 'tc1', 'tc2':'tc2',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='M',
        aliases=['MOSFET', 'mosfet', 'FET', 'fet',],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='metal-oxide field-effect transistor MOSFET',
        description='Metal-oxide field-effect transistor',
        ref_prefix='M',
        pyspice={
            'name': 'M',
            'kw':{
                'model':'model',
                'multiplier':'multiplier', 'm':'multiplier',
                'l':'length', 'length':'length',
                'w':'width', 'width':'width',
                'drain_area':'drain_area',
                'source_area':'source_area',
                'drain_perimeter':'drain_perimeter',
                'source_perimeter':'source_perimeter',
                'drain_number_square':'drain_number_square',
                'source_number_square':'source_number_square',
                'off':'off', 
                'ic':'initial_condition', 'initial_condition':'initial_condition',
                'temp':'temperature', 'temperature':'temperature',
                'd':'drain', 'g':'gate', 's':'source', 'b':'bulk',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='d', func=Pin.PASSIVE, do_erc=True, alias=['drain',]),
            Pin(num='2', name='g', func=Pin.PASSIVE, do_erc=True, alias=['gate',]),
            Pin(num='3', name='s', func=Pin.PASSIVE, do_erc=True, alias=['source',]),
            Pin(num='4', name='b', func=Pin.PASSIVE, do_erc=True, alias=['bulk', 'substrate']),
        ]),
    Part( #####################################################################
        name='N',
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='numerical device GSS',
        description='Numerical device for GSS',
        ref_prefix='N',
        pyspice={
            'name': 'N',
            'add': not_implemented,
        },
        num_units=1,
        do_erc=True,
        pins=[]),
    Part(
        name='O',
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='lossy transmission line',
        description='Lossy transmission line',
        ref_prefix='O',
        pyspice={
            'name': 'O',
            'kw':{
                'model':'model',
                'op':'output_plus', 'on':'output_minus', 'ip':'input_plus', 'in':'input_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='ip', func=Pin.PASSIVE, do_erc=True, alias=_POS_IN_PORT_ALIASES),
            Pin(num='2', name='in', func=Pin.PASSIVE, do_erc=True, alias=_NEG_IN_PORT_ALIASES),
            Pin(num='3', name='op', func=Pin.PASSIVE, do_erc=True, alias=_POS_OUT_PORT_ALIASES),
            Pin(num='4', name='on', func=Pin.PASSIVE, do_erc=True, alias=_NEG_OUT_PORT_ALIASES),
        ]),
    Part(
        name='P',
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='coupled multiconductor line',
        description='Coupled multiconductor line',
        ref_prefix='P',
        pyspice={
            'name': 'P',
            'kw':{
                'model':'model',
                'length':'length', 'l':'length',
                'op':'output_plus', 'on':'output_minus', 'ip':'input_plus', 'in':'input_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[]), #############################################################
    Part(
        name='Q',
        aliases=('BJT', 'bjt'),
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='bipolar transistor npn pnp',
        description='Bipolar Junction Transistor',
        ref_prefix='Q',
        pyspice={
            'name': 'Q',
            'kw':{
                'model':'model', 'area':'area', 'areab':'areab', 'areac':'areac',
                'multiplier':'multiplier', 'm':'multiplier',
                'off':'off', 
                'ic':'initial_condition', 'initial_condition':'initial_condition',
                'temp':'temperature', 'temperature':'temperature',
                'dtemp':'device_temperature', 'device_temperature':'device_temperature',
                'c':'collector', 'b':'base', 'e':'emitter', 's':'substrate',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='c', func=Pin.PASSIVE, do_erc=True, alias=['collector',]),
            Pin(num='2', name='b', func=Pin.PASSIVE, do_erc=True, alias=['base',]),
            Pin(num='3', name='e', func=Pin.PASSIVE, do_erc=True, alias=['emitter',]),
            Pin(num='4', name='s', func=Pin.PASSIVE, do_erc=True, alias=['substrate', 'bulk']),
        ]),
    Part(
        name='R',
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='res resistor',
        description='Resistor',
        ref_prefix='R',
        pyspice={
            'name': 'R',
            'kw':{
                'value':'resistance', 'resistance':'resistance',
                'ac':'ac', 'multiplier':'multiplier', 'm':'multiplier',
                'scale':'scale', 
                'temp':'temperature', 'temperature':'temperature',
                'dtemp':'device_temperature', 'device_temperature':'device_temperature',
                'noisy':'noisy',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='BEHAVRES',
        aliases=['behavres', 'behavioralresistor', 'BEHAVIORALRESISTOR',],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='behavioral resistor',
        description='Behavioral resistor',
        ref_prefix='R',
        pyspice={
            'name': 'BehavioralResistor',
            'kw':{
                'expression':'expression',
                'tc1': 'tc1', 'tc2':'tc2',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='SEMIRES',
        aliases=['semires', 'semiconductorresistor', 'SEMICONDUCTORRESISTOR',],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='semiconductor resistor',
        description='Semiconductor resistor',
        ref_prefix='R',
        pyspice={
            'name': 'SemiconductorResistor',
            'kw':{
                'value':'capacitance', 'capacitance':'capacitance',
                'model':'model',
                'ac':'ac',
                'length':'length', 'l':'length',
                'width':'width', 'w':'width',
                'multiplier':'multiplier', 'm':'multiplier',
                'scale':'scale', 
                'temp':'temperature', 'temperature':'temperature',
                'dtemp':'device_temperature', 'device_temperature':'device_temperature',
                'noisy':'noisy',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='S',
        aliases=['VCS', 'vcs'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='voltage-controlled switch',
        description='Voltage-controlled switch',
        ref_prefix='S',
        pyspice={
            'name': 'S',
            'kw':{
                'model':'model',
                'initial_state':'initial_state',
                'op':'output_plus', 'on':'output_minus', 'ip':'input_plus', 'in':'input_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='ip', func=Pin.PASSIVE, do_erc=True, alias=_POS_IN_PORT_ALIASES),
            Pin(num='2', name='in', func=Pin.PASSIVE, do_erc=True, alias=_NEG_IN_PORT_ALIASES),
            Pin(num='3', name='op', func=Pin.PASSIVE, do_erc=True, alias=_POS_OUT_PORT_ALIASES),
            Pin(num='4', name='on', func=Pin.PASSIVE, do_erc=True, alias=_NEG_OUT_PORT_ALIASES),
        ]),
    Part(
        name='T',
        aliases=['transmissionline', 'TRANSMISSIONLINE'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='transmission line',
        description='Transmission line',
        ref_prefix='T',
        pyspice={
            'name': 'TransmissionLine',
            'add': add_part_to_circuit,
            'kw':{
                'impedance':'impedance', 'Z0':'impedance',
                'time_delay':'time_delay', 'TD':'time_delay',
                'frequency':'frequency', 'F':'frequency',
                'normalized_length':'normalized_length', 'NL':'normalized_length',
                'op':'output_plus', 'on':'output_minus', 'ip':'input_plus', 'in':'input_minus',
            },
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='ip', func=Pin.PASSIVE, do_erc=True, alias=_POS_IN_PORT_ALIASES),
            Pin(num='2', name='in', func=Pin.PASSIVE, do_erc=True, alias=_NEG_IN_PORT_ALIASES),
            Pin(num='3', name='op', func=Pin.PASSIVE, do_erc=True, alias=_POS_OUT_PORT_ALIASES),
            Pin(num='4', name='on', func=Pin.PASSIVE, do_erc=True, alias=_NEG_OUT_PORT_ALIASES),
        ]),
    Part(
        name='U',
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='uniformly-distributed RC line',
        description='Uniformly-distributed RC line',
        ref_prefix='U',
        pyspice={
            'name': 'U',
            'kw': {
                'model':'model',
                'length':'length', 'l':'length',
                'number_of_lumps':'number_of_lumps', 'm':'number_of_lumps',
                'o':'output', 'i':'input', 'cn':'capacitance_node',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='o', func=Pin.PASSIVE, do_erc=True, alias=['output']),
            Pin(num='2', name='i', func=Pin.PASSIVE, do_erc=True, alias=['input',]),
            Pin(num='3', name='cn', func=Pin.PASSIVE, do_erc=True, alias=['cap_node', 'capacitance_node']),
        ]),
    Part(
        name='V',
        aliases=['v', 'VS', 'vs', 'AMMETER', 'ammeter',],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='voltage source',
        description='Voltage source',
        ref_prefix='V',
        pyspice={
            'name': 'V',
            'kw':{
                'value':'dc_value', 'dc_value':'dc_value',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='W',
        aliases=['CCS', 'ccs'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='current-controlled switch',
        description='Current-controlled switch',
        ref_prefix='W',
        pyspice={
            'name': 'W',
            'kw':{
                'control':'source', 'source':'source', 'model':'model',
                'initial_state':'initial_state',
                'p':'plus', 'n':'minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    # Part( #####################################################################
        # name='X',
        # dest=TEMPLATE,
        # tool=SKIDL,
        # keywords='subcircuit',
        # description='Subcircuit',
        # ref_prefix='Y',
        # pyspice={
            # 'name': 'SubCircuitElement',
            # 'add': _add_subcircuit_to_circuit,
        # },
        # num_units=1,
        # do_erc=True,
        # pins=[]),
    Part(
        name='Y',
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='single lossy transmission line',
        description='Single lossy transmission line',
        ref_prefix='Y',
        pyspice={
            'name': 'Y',
            'kw':{
                'model':'model',
                'length':'length', 'l':'length',
                'op':'output_plus', 'on':'output_minus', 'ip':'input_plus', 'in':'input_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='ip', func=Pin.PASSIVE, do_erc=True, alias=_POS_IN_PORT_ALIASES),
            Pin(num='2', name='in', func=Pin.PASSIVE, do_erc=True, alias=_NEG_IN_PORT_ALIASES),
            Pin(num='3', name='op', func=Pin.PASSIVE, do_erc=True, alias=_POS_OUT_PORT_ALIASES),
            Pin(num='4', name='on', func=Pin.PASSIVE, do_erc=True, alias=_NEG_OUT_PORT_ALIASES),
        ]),
    Part(
        name='Z',
        aliases=['MESFET', 'mesfet'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='metal-semiconductor field-effect transistor MOSFET',
        description='Metal-semiconductor field-effect transistor',
        ref_prefix='Z',
        pyspice={
            'name': 'Z',
            'kw':{
                'model':'model',
                'area':'area',
                'multiplier':'multiplier', 'm':'multiplier',
                'off':'off', 
                'ic':'initial_condition', 'initial_condition':'initial_condition',
                'd':'drain', 'g':'gate', 's':'source',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='d', func=Pin.PASSIVE, do_erc=True, alias=['drain',]),
            Pin(num='2', name='g', func=Pin.PASSIVE, do_erc=True, alias=['gate',]),
            Pin(num='3', name='s', func=Pin.PASSIVE, do_erc=True, alias=['source',]),
        ]),
    Part(
        name='SINEV',
        aliases=['sinev', 'sinusoidalvoltage', 'SINUSOIDALVOLTAGE'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='simusoidal voltage source',
        description='Sinusoidal voltage source',
        ref_prefix='V',
        pyspice={
            'name': 'SinusoidalVoltageSource',
            'kw':{
                'dc_offset':'dc_offset', 'offset':'offset',
                'amplitude':'amplitude', 'frequency':'frequency',
                'delay':'delay', 'damping_factor':'damping_factor',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='SINEI',
        aliases=['sinei', 'sinusoidalcurrent', 'SINUSOIDALCURRENT'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='simusoidal current source',
        description='Sinusoidal current source',
        ref_prefix='I',
        pyspice={
            'name': 'SinusoidalCurrentSource',
            'kw':{
                'dc_offset':'dc_offset', 'offset':'offset',
                'amplitude':'amplitude', 'frequency':'frequency',
                'delay':'delay', 'damping_factor':'damping_factor',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='PULSEV',
        aliases=['pulsev', 'pulsevoltage', 'PULSEVOLTAGE'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='pulsed voltage source',
        description='Pulsed voltage source',
        ref_prefix='V',
        pyspice={
            'name': 'PulseVoltageSource',
            'kw':{
                'initial_value':'initial_value', 'pulsed_value':'pulsed_value',
                'delay_time':'delay_time', 'rise_time':'rise_time',
                'fall_time':'fall_time', 'pulse_width':'pulse_width',
                'period':'period',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='PULSEI',
        aliases=['pulsei', 'pulsecurrent', 'PULSECURRENT'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='pulsed current source',
        description='Pulsed current source',
        ref_prefix='I',
        pyspice={
            'name': 'PulseCurrentSource',
            'kw':{
                'initial_value':'initial_value', 'pulsed_value':'pulsed_value',
                'delay_time':'delay_time', 'rise_time':'rise_time',
                'fall_time':'fall_time', 'pulse_width':'pulse_width',
                'period':'period',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='EXPV',
        aliases=['expv', 'exponentialvoltage', 'EXPONENTIALVOLTAGE'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='exponential voltage source',
        description='Exponential voltage source',
        ref_prefix='V',
        pyspice={
            'name': 'ExponentialVoltageSource',
            'kw':{
                'initial_value':'initial_value', 'pulsed_value':'pulsed_value',
                'rise_delay_time':'rise_delay_time', 'rise_time_constant':'rise_time_constant',
                'fall_delay_time':'fall_delay_time', 'fall_time_constant':'fall_time_constant',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='EXPI',
        aliases=['expi', 'exponentialcurrent', 'EXPONENTIALCURRENT'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='exponential current source',
        description='Exponential current source',
        ref_prefix='I',
        pyspice={
            'name': 'ExponentialCurrentSource',
            'kw':{
                'initial_value':'initial_value', 'pulsed_value':'pulsed_value',
                'rise_delay_time':'rise_delay_time', 'rise_time_constant':'rise_time_constant',
                'fall_delay_time':'fall_delay_time', 'fall_time_constant':'fall_time_constant',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='PWLV',
        aliases=['pwlv', 'piecewiselinearvoltage', 'PIECEWISELINEARVOLTAGE'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='piecewise linear voltage source',
        description='Piecewise linear voltage source',
        ref_prefix='V',
        pyspice={
            'name': 'PieceWiseLinearVoltageSource',
            'kw':{
                'values':'values', 'repeate_time':'repeate_time',
                'delay_time':'delay_time',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='PWLI',
        aliases=['pwli', 'piecewiselinearcurrent', 'PIECEWISELINEARCURRENT'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='piecewise linear current source',
        description='Piecewise linear current source',
        ref_prefix='I',
        pyspice={
            'name': 'PieceWiseLinearCurrentSource',
            'kw':{
                'values':'values', 'repeate_time':'repeate_time',
                'delay_time':'delay_time',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='FMV',
        aliases=['fmv', 'SFFMV', 'sffmv', 'SINGLEFREQUENCYFMVOLTAGE', 'singlefrequencyfmvoltage'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='single frequency FM modulated voltage source',
        description='Single-frequency FM-modulated voltage source',
        ref_prefix='V',
        pyspice={
            'name': 'SingleFrequencyFMVoltageSource',
            'kw':{
                'offset':'offset', 'amplitude':'amplitude',
                'carrier_frequency':'carrier_frequency',
                'modulation_index':'modulation_index',
                'signal_frequency':'signal_frequency',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='FMI',
        aliases=['fmi', 'SFFMI', 'sffmi', 'SINGLEFREQUENCYFMCURRENT', 'singlefrequencyfmcurrent'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='single frequency FM modulated current source',
        description='Single-frequency FM-modulated current source',
        ref_prefix='I',
        pyspice={
            'name': 'SingleFrequencyFMCurrentSource',
            'kw':{
                'offset':'offset', 'amplitude':'amplitude',
                'carrier_frequency':'carrier_frequency',
                'modulation_index':'modulation_index',
                'signal_frequency':'signal_frequency',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='AMV',
        aliases=['amv', 'AMPLITUDEMODULATEDVOLTAGE', 'amplitudemodulatedvoltage'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='amplitude modulated voltage source',
        description='Amplitude-modulated voltage source',
        ref_prefix='V',
        pyspice={
            'name': 'AmplitudeModulatedVoltageSource',
            'kw':{
                'offset':'offset', 'amplitude':'amplitude',
                'carrier_frequency':'carrier_frequency',
                'modulating_frequency':'modulating_frequency',
                'signal_delay':'signal_delay',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='AMI',
        aliases=['ami', 'AMPLITUDEMODULATEDCURRENT', 'amplitudemodulatedcurrent'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='amplitude modulated current source',
        description='Amplitude-modulated current source',
        ref_prefix='I',
        pyspice={
            'name': 'AmplitudeModulatedCurrentSource',
            'kw':{
                'offset':'offset', 'amplitude':'amplitude',
                'carrier_frequency':'carrier_frequency',
                'modulating_frequency':'modulating_frequency',
                'signal_delay':'signal_delay',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='RNDV',
        aliases=['rndv', 'RANDOMVOLTAGE', 'randomvoltage'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='random voltage source',
        description='Random voltage source',
        ref_prefix='V',
        pyspice={
            'name': 'RandomVoltageSource',
            'kw':{
                'random_type':'random_type', 'duration':'duration',
                'time_delay':'time_delay',
                'parameter1':'parameter1',
                'parameter2':'parameter2',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
    Part(
        name='RNDI',
        aliases=['rndi', 'RANDOMCURRENT', 'randomcurrent'],
        dest=TEMPLATE,
        tool=SKIDL,
        keywords='random current source',
        description='Random current source',
        ref_prefix='I',
        pyspice={
            'name': 'RandomCurrentSource',
            'kw':{
                'random_type':'random_type', 'duration':'duration',
                'time_delay':'time_delay',
                'parameter1':'parameter1',
                'parameter2':'parameter2',
                'p':'node_plus', 'n':'node_minus',
            },
            'add': add_part_to_circuit,
        },
        num_units=1,
        do_erc=True,
        pins=[
            Pin(num='1', name='p', func=Pin.PASSIVE, do_erc=True, alias=_POS_DIPOLE_ALIASES),
            Pin(num='2', name='n', func=Pin.PASSIVE, do_erc=True, alias=_NEG_DIPOLE_ALIASES),
        ]),
])



from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

audio = SchLib(tool=SKIDL).add_parts(*[
        Part(name='LL1587',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='LM1875',dest=TEMPLATE,tool=SKIDL,keywords='LM1875 Amplifier 20W',description='20W Audio Power Amplifier, TO220-5',ref_prefix='U',num_units=1,fplist=['TO*'],do_erc=True,pins=[
            Pin(num='1',name='IN+',do_erc=True),
            Pin(num='2',name='IN-',do_erc=True),
            Pin(num='3',name='VEE',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LM1876',dest=TEMPLATE,tool=SKIDL,keywords='LM1876 Overture Amplifier Dual 20W',description='Dual 20W Overture Seriers Audio Power Amplifier, with Mute Standby Mode, TO220-15 (MultiWatt)',ref_prefix='U',num_units=2,fplist=['TO*'],do_erc=True,pins=[
            Pin(num='2',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='VEE',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='MUTE',do_erc=True),
            Pin(num='7',name='IN-',do_erc=True),
            Pin(num='8',name='IN+',do_erc=True),
            Pin(num='9',name='STB',do_erc=True),
            Pin(num='1',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='VEE',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='MUTE',do_erc=True),
            Pin(num='12',name='IN-',do_erc=True),
            Pin(num='13',name='IN+',do_erc=True),
            Pin(num='14',name='STB',do_erc=True),
            Pin(num='15',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LM1877M',dest=TEMPLATE,tool=SKIDL,keywords='Dual Audio Amplifier 2W 24V',description='2W/8R Dual Audio Power Amplifier, Supply Voltage 6-24V, SO14L',ref_prefix='U',num_units=1,fplist=['SO*'],do_erc=True,pins=[
            Pin(num='1',name='BIAS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='OUT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='IN1',do_erc=True),
            Pin(num='7',name='IN1',do_erc=True),
            Pin(num='8',name='IN2',do_erc=True),
            Pin(num='9',name='IN2',do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='OUT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='V+',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LM1877N',dest=TEMPLATE,tool=SKIDL,keywords='Dual Audio Amplifier 2W 24V',description='2W/8R Dual Audio Power Amplifier, Supply Voltage 6-24V, DIP14',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*'],do_erc=True,pins=[
            Pin(num='1',name='BIAS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='OUT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='IN1',do_erc=True),
            Pin(num='7',name='IN1',do_erc=True),
            Pin(num='8',name='IN2',do_erc=True),
            Pin(num='9',name='IN2',do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='OUT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='V+',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LM3886T',dest=TEMPLATE,tool=SKIDL,keywords='LM3886 Overture Amplifier Single 86W',description='Single 68W Overture Seriers Audio Power Amplifier, with Mute Mode, PFM-11 (Plastic MultiWatt)',ref_prefix='U',num_units=1,fplist=['TO*'],do_erc=True,aliases=['LM3886TF'],pins=[
            Pin(num='1',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='V-',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='MUTE',do_erc=True),
            Pin(num='9',name='IN-',do_erc=True),
            Pin(num='10',name='IN+',do_erc=True)]),
        Part(name='LM4950TA',dest=TEMPLATE,tool=SKIDL,keywords='LM4950 Stereo Power Aplifier 3.1W',description='Audio 3.1W Stereo Power Amplifier, TO220-9',ref_prefix='U',num_units=1,fplist=['TO220*'],do_erc=True,pins=[
            Pin(num='1',name='INA',do_erc=True),
            Pin(num='2',name='~SHD~',do_erc=True),
            Pin(num='3',name='OUTA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='OUTB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='BP',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='INB',do_erc=True),
            Pin(num='10',name='TAP',do_erc=True)]),
        Part(name='LM4950TS',dest=TEMPLATE,tool=SKIDL,keywords='LM4950 Stereo Power Aplifier 3.1W',description='Audio 3.1W Stereo Power Amplifier, TO263-9',ref_prefix='U',num_units=1,fplist=['TO263*'],do_erc=True,pins=[
            Pin(num='1',name='INA',do_erc=True),
            Pin(num='2',name='~SHD~',do_erc=True),
            Pin(num='3',name='OUTA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='OUTB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='BP',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='INB',do_erc=True),
            Pin(num='10',name='TAP',do_erc=True)]),
        Part(name='LM4990',dest=TEMPLATE,tool=SKIDL,keywords='Audio Boomer BTL Mono Amplifier',description='Audio 1.25W Mono Power Amplifier, VSSOP',ref_prefix='U',num_units=1,fplist=['MSOP-*_3x3mm_Pitch0.65mm*'],do_erc=True,pins=[
            Pin(num='1',name='~SHTD',do_erc=True),
            Pin(num='2',name='BYPS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='+IN',do_erc=True),
            Pin(num='4',name='-IN',do_erc=True),
            Pin(num='5',name='VO1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VO2',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='MSGEQ7',dest=TEMPLATE,tool=SKIDL,keywords='equalizer filter',description='Graphic Equalizer Display Filter',ref_prefix='U',num_units=1,fplist=['SOIC*', 'DIP*'],do_erc=True,pins=[
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='STROBE',do_erc=True),
            Pin(num='5',name='IN',do_erc=True),
            Pin(num='6',name='GND',func=Pin.PWROUT,do_erc=True),
            Pin(num='7',name='RESET',do_erc=True),
            Pin(num='8',name='CKIN',do_erc=True)]),
        Part(name='NSL-32',dest=TEMPLATE,tool=SKIDL,keywords='OPTO',description='Opto resistor',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='R',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='R',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='PAM8301',dest=TEMPLATE,tool=SKIDL,keywords='Audio Mono Filterless Class-D Amplifier',description='Audio 1.5W Filterless Class-D Mono Amplifier, TSOT-23-6',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='OUT-',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='IN',do_erc=True),
            Pin(num='4',name='~SD',do_erc=True),
            Pin(num='5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='OUT+',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='PGA4311',dest=TEMPLATE,tool=SKIDL,keywords='AUDIO',description='4 channels Audio Volume Control',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='MUTE',do_erc=True),
            Pin(num='2',name='AGND-1',do_erc=True),
            Pin(num='3',name='Ain-1',do_erc=True),
            Pin(num='4',name='AGND-1',do_erc=True),
            Pin(num='5',name='Ain-1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VA-',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VA+',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Aout-3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='AGND-3',do_erc=True),
            Pin(num='10',name='Ain-3',do_erc=True),
            Pin(num='20',name='AGND_4',do_erc=True),
            Pin(num='11',name='AGND-3',do_erc=True),
            Pin(num='21',name='Aout-4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='VD+',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VA+',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='SDI',do_erc=True),
            Pin(num='23',name='VA-',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='CS',do_erc=True),
            Pin(num='24',name='Aout-2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='SCLK',do_erc=True),
            Pin(num='25',name='AGND-2',do_erc=True),
            Pin(num='16',name='SDO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='26',name='Ain-2',do_erc=True),
            Pin(num='17',name='DGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='AGND-2',do_erc=True),
            Pin(num='18',name='AGND_4',do_erc=True),
            Pin(num='28',name='ZCEN',do_erc=True),
            Pin(num='19',name='Ain-4',do_erc=True)]),
        Part(name='SSM-2017P',dest=TEMPLATE,tool=SKIDL,keywords='Audio PREAMP',description='Audio low noise preamp',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='Gain',do_erc=True),
            Pin(num='2',name='-',do_erc=True),
            Pin(num='3',name='+',do_erc=True),
            Pin(num='4',name='V-',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Ref',do_erc=True),
            Pin(num='6',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Gain',do_erc=True)]),
        Part(name='SSM-2018T',dest=TEMPLATE,tool=SKIDL,keywords='AUDIO VCA',description='audio VCA',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='9',name='Comp3',do_erc=True),
            Pin(num='1',name='+I1-G',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='-Ig',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='-I1-G',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='Comp1',do_erc=True),
            Pin(num='6',name='+',do_erc=True),
            Pin(num='7',name='-',do_erc=True),
            Pin(num='8',name='Comp2',do_erc=True),
            Pin(num='10',name='V-',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='Vctrl',do_erc=True),
            Pin(num='12',name='MODE',do_erc=True),
            Pin(num='13',name='GND',do_erc=True),
            Pin(num='14',name='Vg',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='BAL',do_erc=True),
            Pin(num='16',name='V1-g',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='SSM2120P',dest=TEMPLATE,tool=SKIDL,keywords='AUDIO VCA',description='Dual VCA & level detectors',ref_prefix='U',num_units=2,do_erc=True,pins=[
            Pin(num='10',name='Iref',do_erc=True),
            Pin(num='11',name='V-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='Thresh',do_erc=True),
            Pin(num='2',name='LOGav',do_erc=True),
            Pin(num='3',name='CTR',do_erc=True),
            Pin(num='4',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='+Vc',do_erc=True),
            Pin(num='6',name='CFT',do_erc=True),
            Pin(num='7',name='-Vc',do_erc=True),
            Pin(num='8',name='E',do_erc=True),
            Pin(num='9',name='RecIn',do_erc=True),
            Pin(num='20',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='Thresh',do_erc=True),
            Pin(num='13',name='LOGav',do_erc=True),
            Pin(num='14',name='CTR',do_erc=True),
            Pin(num='15',name='RecIn',do_erc=True),
            Pin(num='16',name='E',do_erc=True),
            Pin(num='17',name='-Vc',do_erc=True),
            Pin(num='18',name='CFT',do_erc=True),
            Pin(num='19',name='+Vc',do_erc=True)]),
        Part(name='SSM2122P',dest=TEMPLATE,tool=SKIDL,keywords='AUDIO VCA',description='Dual VCA',ref_prefix='U',num_units=2,do_erc=True,pins=[
            Pin(num='7',name='Iref',do_erc=True),
            Pin(num='8',name='V-',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='+Vc',do_erc=True),
            Pin(num='4',name='CFT',do_erc=True),
            Pin(num='5',name='-Vc',do_erc=True),
            Pin(num='6',name='E',do_erc=True),
            Pin(num='10',name='E',do_erc=True),
            Pin(num='11',name='-Vc',do_erc=True),
            Pin(num='12',name='CFT',do_erc=True),
            Pin(num='13',name='+Vc',do_erc=True),
            Pin(num='14',name='~',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='SSM2165',dest=TEMPLATE,tool=SKIDL,keywords='AUDIO',description='8 pins microphone preamp and compressor',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='VCAIN',do_erc=True),
            Pin(num='3',name='BUFOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='IN+',do_erc=True),
            Pin(num='5',name='AVG',do_erc=True),
            Pin(num='6',name='COMP',do_erc=True),
            Pin(num='7',name='VOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='V+',func=Pin.PWRIN,do_erc=True)]),
        Part(name='SSM2210',dest=TEMPLATE,tool=SKIDL,description='Audio dual matched NPN transistor',ref_prefix='U',num_units=2,do_erc=True,pins=[
            Pin(num='1',name='C',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='B',do_erc=True),
            Pin(num='3',name='E',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='E',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='B',do_erc=True),
            Pin(num='8',name='C',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='SSM2220',dest=TEMPLATE,tool=SKIDL,keywords='AUDIO',description='Audiao dual Matched PNP transistor (low noise)',ref_prefix='U',num_units=2,do_erc=True,pins=[
            Pin(num='1',name='C',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='B',do_erc=True),
            Pin(num='3',name='E',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='E',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='B',do_erc=True),
            Pin(num='8',name='C',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='STK435',dest=TEMPLATE,tool=SKIDL,keywords='STK443 Dual 25W Amplifier Audio',description='Dual 25W Audio Power Amplifier, 4010',ref_prefix='U',num_units=2,do_erc=True,aliases=['STK433', 'STK436', 'STK437', 'STK439', 'STK441', 'STK443'],pins=[
            Pin(num='1',name='IN+',do_erc=True),
            Pin(num='2',name='IN-',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='BST',do_erc=True),
            Pin(num='7',name='VCC',do_erc=True),
            Pin(num='8',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VCC2',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VCC',do_erc=True),
            Pin(num='8',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VCC2',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='BST',do_erc=True),
            Pin(num='11',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='IN-',do_erc=True),
            Pin(num='15',name='IN+',do_erc=True)]),
        Part(name='TDA2003H',dest=TEMPLATE,tool=SKIDL,keywords='TDA2003H Amplifier 10W Pentawatt',description='10W Car Radio Audio Amplifier, TO220-5 (PentaWatt5H)',ref_prefix='U',num_units=1,fplist=['TO*'],do_erc=True,pins=[
            Pin(num='1',name='IN+',do_erc=True),
            Pin(num='2',name='IN-',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TDA2003V',dest=TEMPLATE,tool=SKIDL,keywords='TDA2003V Amplifier 10W Pentawatt',description='10W Car Radio Audio Amplifier, PentaWatt5V',ref_prefix='U',num_units=1,fplist=['TO*'],do_erc=True,pins=[
            Pin(num='1',name='IN+',do_erc=True),
            Pin(num='2',name='IN-',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TDA2005R',dest=TEMPLATE,tool=SKIDL,keywords='TDA2005 Amplifier 20W Multiwatt',description='20W Bidge/Stereo Audio Amplifier for Car Radio, TO220-11 (MultiWatt11)',ref_prefix='U',num_units=2,fplist=['TO*'],do_erc=True,pins=[
            Pin(num='3',name='SVRR',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='IN+',do_erc=True),
            Pin(num='2',name='IN-',do_erc=True),
            Pin(num='10',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='BST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='IN-',do_erc=True),
            Pin(num='5',name='IN+',do_erc=True),
            Pin(num='7',name='BST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='OUT',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='TDA2030',dest=TEMPLATE,tool=SKIDL,keywords='TDA2030 Amplifier14W Pentawatt',description='14W Hi-Fi Audio Amplifier, TO220-5 (PentaWatt)',ref_prefix='U',num_units=1,fplist=['TO*'],do_erc=True,pins=[
            Pin(num='1',name='IN+',do_erc=True),
            Pin(num='2',name='IN-',do_erc=True),
            Pin(num='3',name='VEE',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TDA2050',dest=TEMPLATE,tool=SKIDL,keywords='TDA2050 Amplifier 32W Pentawatt',description='32W Hi-Fi Audio Amplifier, TO220-5 (PentaWatt)',ref_prefix='U',num_units=1,fplist=['TO*'],do_erc=True,pins=[
            Pin(num='1',name='IN+',do_erc=True),
            Pin(num='2',name='IN-',do_erc=True),
            Pin(num='3',name='VEE',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TDA7294HS',dest=TEMPLATE,tool=SKIDL,keywords='TDA7294 Amplifier Single 100W',description='Single 100W Audio Power Amplifier, with Mute and Standby Mode, MultiWatt15H',ref_prefix='U',num_units=1,fplist=['TO*'],do_erc=True,pins=[
            Pin(num='1',name='STBY-GND',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='IN-',do_erc=True),
            Pin(num='3',name='IN+',do_erc=True),
            Pin(num='4',name='IN+MUTE',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='BST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='Vs+',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Vs-',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='STBY',do_erc=True),
            Pin(num='10',name='MUTE',do_erc=True),
            Pin(num='13',name='PWVs+',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='PWVs-',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TDA7294V',dest=TEMPLATE,tool=SKIDL,keywords='TDA7294 Amplifier Single 100W',description='Single 100W Audio Power Amplifier, with Mute and Standby Mode, TO220-15 (MultiWatt15V)',ref_prefix='U',num_units=1,fplist=['TO*'],do_erc=True,pins=[
            Pin(num='1',name='STBY-GND',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='IN-',do_erc=True),
            Pin(num='3',name='IN+',do_erc=True),
            Pin(num='4',name='IN+MUTE',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='BST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='Vs+',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Vs-',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='STBY',do_erc=True),
            Pin(num='10',name='MUTE',do_erc=True),
            Pin(num='13',name='PWVs+',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='PWVs-',func=Pin.PWRIN,do_erc=True)]),
        Part(name='THAT2180',dest=TEMPLATE,tool=SKIDL,keywords='AUDIO VCA',description='VCA (THAT Corporation)',ref_prefix='U',num_units=1,do_erc=True,aliases=['THAT2181'],pins=[
            Pin(num='5',name='V-',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='1',name='E',do_erc=True),
            Pin(num='2',name='+Vc',do_erc=True),
            Pin(num='3',name='-Vc',do_erc=True),
            Pin(num='4',name='Sym',do_erc=True),
            Pin(num='8',name='~',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='TR-AUDIO-2P',dest=TEMPLATE,tool=SKIDL,keywords='TRANSFO',description='Microphone Input Transformer (2 P 1S)',ref_prefix='T',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='P1+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='P1-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='P2-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='P2+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='S-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='S+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='~',do_erc=True)])])